@@ -1,15 +1,14 @@
 from os import path
+import sys
 
-__version__ = '0.9.9'
+from . import context  # noqa
+from . import op  # noqa
+from .runtime import environment
+from .runtime import migration
+
+__version__ = "1.0.6"
 
 package_dir = path.abspath(path.dirname(__file__))
 
-
-from . import op  # noqa
-from . import context  # noqa
-
-import sys
-from .runtime import environment
-from .runtime import migration
-sys.modules['alembic.migration'] = migration
-sys.modules['alembic.environment'] = environment
+sys.modules["alembic.migration"] = migration
+sys.modules["alembic.environment"] = environment
